@@ -2,5 +2,5 @@ from .cdn import AliCdnDomain
 from .nas import AliNas
 from .dds import AliMongoDB
 from .kafka import AliKafka
-from .vpn import AliVpn, AliCustomer, AliIPsec
+from .vpn import AliVpn, AliCustomer, AliIPsec, AliRouteEntry
 
