@@ -4,6 +4,7 @@ from .nas_client import NasClient
 from .dds_client import DdsClient
 from .kafka_client import KafkaClient
 from .order_client import OrderClient
+from .vpn_client import VpnGatewayClient
 from proxy_tools import proxy
 
 
@@ -12,7 +13,8 @@ prod_mapper = {
     'nas': NasClient,
     'dds': DdsClient,
     'kafka': KafkaClient,
-    'order': OrderClient
+    'order': OrderClient,
+    'vpn': VpnGatewayClient
 }
 
 
@@ -46,3 +48,8 @@ def kafka_client():
 @proxy
 def order_client():
     return get_current_client('order')
+
+
+@proxy
+def vpn_client():
+    return get_current_client('vpn')
\ No newline at end of file
