@@ -1,6 +1,6 @@
 from .client import HuaweiClient
 from huaweicloudsdkeip.v2 import EipClient, CreatePrePaidPublicipRequest, DeletePublicipRequest, ShowPublicipRequest, \
-    UpdatePublicipRequest
+    UpdatePublicipRequest, ListPublicipsRequest
 from huaweicloudsdkeip.v2.region.eip_region import EipRegion
 
 
@@ -28,5 +28,11 @@ class HuaweiEipClient(HuaweiClient):
         request = UpdatePublicipRequest(publicip_id=publicip_id, body=body_params)
         return self.eip_client.update_publicip(request).publicip
 
+    def list_eip(self):
+        request = ListPublicipsRequest()
+        return self.eip_client.list_publicips(request).publicips
+
+
+
 
 
